@@ -4,7 +4,6 @@ from to_precision import auto_notation
 from scipy.constants import nano, kilo, milli, centi, liter, minute, day, hour
 from itertools import chain
 from chempy.properties.water_density_tanaka_2001 import water_density
-import phreeqpy.iphreeqc.phreeqc_com as phreeqc_mod
 from pubchempy import get_compounds 
 from chemicals import periodic_table
 import subprocess
@@ -35,21 +34,28 @@ def time_determination(time):
 
 
 class ROSSPkg():
-    def __init__(self, verbose = False, jupyter = False):       
+    def __init__(self, operating_system = 'windows', verbose = False, jupyter = False):      
         # establish the general organization structures
         self.parameters = {}
         self.variables = {}
         self.results = {}
         self.results['figures'] = {}
         self.verbose = verbose
+        if operating_system == 'mac':
+            import phreeqpy.iphreeqc.phreeqc_dll as phreeqc_mod
+        elif operating_system == 'windows':
+            import phreeqpy.iphreeqc.phreeqc_com as phreeqc_mod
+        else:
+            print(f'--> ERROR: The operating system {operating_system} is not supported.')
+        self.phreeqc_mod = phreeqc_mod
+        self.parameters['os'] =  operating_system
         
-    def define_general(self, phreeqc_path, database_selection, simulation = 'scaling', domain = 'single', domain_phase = None, quantity_of_modules = 1, simulation_type = 'transport', operating_system = 'windows', simulation_title = None):
+    def define_general(self, phreeqc_path, database_selection, simulation = 'scaling', domain = 'single', domain_phase = None, quantity_of_modules = 1, simulation_type = 'transport', simulation_title = None):
         '''Establish general conditions'''
         self.parameters['water_mw'] = float(get_compounds('water', 'name')[0].molecular_weight)
         self.parameters['water_grams_per_liter'] = water_density()
         
         # parameterize the input file
-        self.parameters['os'] =  operating_system
         self.parameters['phreeqc_path'] = phreeqc_path
         self.parameters['simulation_type'] = simulation_type
         self.parameters['simulation'] = simulation
@@ -60,7 +66,7 @@ class ROSSPkg():
         database_path = os.path.join(self.parameters['root_path'], 'databases', f'{database_selection}.json') 
         
         title_line = f'TITLE\t {simulation_title}'
-        if operating_system == 'Windows':
+        if self.parameters['os'] == 'Windows':
             database_line = f'DATABASE {database_path}'
             self.results['general_conditions'] = [database_line, title_line]
         else:
@@ -629,7 +635,7 @@ class ROSSPkg():
         database_path = os.path.join(self.parameters['phreeqc_path'], 'database\\{}.dat'.format(self.parameters['database_selection']))
 
         def run(input_file, first=False):
-            phreeqc = phreeqc_mod.IPhreeqc()                 
+            phreeqc = self.phreeqc_mod.IPhreeqc()                 
             phreeqc.load_database(database_path)
             phreeqc.run_string(input_file)
             
@@ -661,8 +667,8 @@ class ROSSPkg():
             headers = conc.keys()
             self.results['csv_data'] = pandas.DataFrame(conc, columns = headers)
             if self.verbose:
-                pandas.set_option('display.max_columns', None)
                 if jupyter:
+                    pandas.set_option('display.max_columns', None)
                     display(self.results['csv_data'])
                 else:
                     print(self.results['csv_data'])
